@@ -12,8 +12,8 @@ class MicrosoftAuth2Adapter(OAuth2Adapter):
     settings = app_settings.PROVIDERS.get(provider_id, {})
     tenant = settings.get("TENANT")
 
-    authorize_url = "https://login.microsoftonline.com/{tenant}/oauth2/v2.0/authorize".format(tenant=tenant)
-    access_token_url = "https://login.microsoftonline.com/{tenant}/oauth2/v2.0/token".format(tenant=tenant)
+    authorize_url = "https://login.microsoftonline.com/common/{tenant}/oauth2/v2.0/authorize".format(tenant=tenant)
+    access_token_url = "https://login.microsoftonline.com/common/{tenant}/oauth2/v2.0/token".format(tenant=tenant)
     profile_url = "https://graph.microsoft.com/v1.0/me"
 
     def complete_login(self, request, app, token, **kwargs):
